import java.util.ArrayList;
import java.util.Collections;
import java.util.Comparator;

class Eintrag {

	private String begriff;
	private ArrayList<Integer> seiten;

	Eintrag(String begriff, int seitenzahl) {
		this.begriff = new String(begriff);
		this.seiten = new ArrayList<Integer>();
		this.seiten.add(seitenzahl);
	}

	Eintrag(Eintrag other) {
		this.begriff = new String(other.begriff);
		this.seiten = new ArrayList<Integer>();
		for (Integer i : other.seiten) {
			this.seiten.add(i);
		}
	}

	@Override
	public String toString() {
		String erg = new String(this.begriff);
		erg += ": ";
		for (int seitenzahl : this.seiten) {
			erg += seitenzahl + " ";
		}
		return erg;
	}

	boolean neueSeite(int seitenzahl) {
		if (!this.seiten.contains(seitenzahl)) {
			this.seiten.add(seitenzahl);

			// Sortieren der Seitenzahlen
			Collections.sort(seiten);
			return true;
		} else {
			return false; // war schon drin
		}
	}

	String getBegriff() {
		return this.begriff;
	}

}

// Hilfsklasse zum Sortieren der Eintraege
class EintragComparator implements Comparator<Eintrag> {
	@Override
	public int compare(Eintrag e1, Eintrag e2) {
		return e1.getBegriff().compareToIgnoreCase(e2.getBegriff());
	}
}

class Index {

	private ArrayList<Eintrag> eintraege;

	public Index() {
		this.eintraege = new ArrayList<Eintrag>();
	}

	public Index(Index other) {
		this.eintraege = new ArrayList<Eintrag>();
		for (Eintrag e : other.eintraege) {
			this.eintraege.add(new Eintrag(e));
		}
	}

	@Override
	protected Index clone() {
		return new Index(this);
	}

	@Override
	public String toString() {
		String erg = "";

		for (Eintrag eintrag : this.eintraege) {
			erg += eintrag.toString() + "\n";
		}
		return erg;
	}

	public void hinzufuegen(String begriff, int seitenzahl) {
		Eintrag eintrag = this.getEintrag(begriff);
		if (eintrag == null) {
			eintrag = new Eintrag(begriff, seitenzahl);
			this.eintraege.add(eintrag);

			// Sortieren der Eintraege
			Collections.sort(eintraege, new EintragComparator());
		} else {
			eintrag.neueSeite(seitenzahl);
		}
	}

	private Eintrag getEintrag(String begriff) {
		for (Eintrag eintrag : this.eintraege) {
			if (eintrag.getBegriff().equals(begriff)) {
				return eintrag;
			}
		}
		return null;
	}
}

public class UE16Aufgabe10 {

	// Testprogramm
	public static void main(String[] args) {
		Index index = new Index();

		index.hinzufuegen("Objekt", 1);
		index.hinzufuegen("Objekt", 15);
		index.hinzufuegen("Objekt", 3);
		index.hinzufuegen("Objekt", 15);

		Index index2 = new Index(index);

		index.hinzufuegen("Hamster", 45);
		index.hinzufuegen("Hamster", 2);
		index.hinzufuegen("Hamster", 199);
		index.hinzufuegen("Hamster", 45);

		System.out.println(index);
		System.out.println(index2);
	}
}
